import co.ecg.alpaca.toolkit.BroadWorksServer;
import co.ecg.alpaca.toolkit.generated.SystemAccessDevice.SystemAccessDeviceGetAllRequest;
import co.ecg.alpaca.toolkit.generated.SystemAccessDevice.SystemAccessDeviceGetAllResponse;
import co.ecg.alpaca.toolkit.generated.tables.SystemAccessDeviceAccessDeviceTable;
import co.ecg.utilities.P;

/**
 * Tool to retrieve all display all Access Devices in the BroadWorks system
 * without a specific MAC address.
 *
 * @author Matthew Keathley - mkeathley@e-c-group.com
 */
public class DeviceWithEmptyMACReport {

    public static void main(String[] args) {
        try {
            // Retrieves the Server, Username, and Password from the
            // alpaca.properties.xml file
            String server = P.CoreProperties.getPrimaryBroadWorksServerAddress();
            String username = P.CoreProperties.getPrimaryBroadWorksUserId();
            String password = P.CoreProperties.getPrimaryBroadWorksPassword();

            // Open the connection to BroadWorks
            BroadWorksServer bws = BroadWorksServer.getBroadWorksServer(server, username, password);

            // Create Request
            SystemAccessDeviceGetAllRequest accessDeviceGetAllRequest = new SystemAccessDeviceGetAllRequest(bws);

            // Perform a synchronous fire to receive Response
            SystemAccessDeviceGetAllResponse accessDeviceGetAllResponse = accessDeviceGetAllRequest.fire();

            // Check if the Response is an Error
            if (accessDeviceGetAllResponse.isErrorResponse()) {
                System.out.println("Error while retrieving devices - " + accessDeviceGetAllResponse.getSummaryText());
                System.exit(1);
            }

            // Iterate over the Table Rows
            for (SystemAccessDeviceAccessDeviceTable.Row r : accessDeviceGetAllResponse.getAccessDeviceTable().getRows()) {
                // Print the basic device information if the MAC address is empty
                if (r.getMACAddress().isEmpty()) {
                    System.out.println(r.getServiceProviderId()
                        + "\t" + r.getGroupId() + "\t" + r.getDeviceName() + "\t" + r.getDeviceType());
                }
            }

            System.exit(0);
        } catch (Exception ex) {
            System.out.println("Error while generating empty MAC device report - " + ex.getMessage());
            System.exit(1);
        }
    }
}
